@@ -5,6 +5,8 @@ use strict;
 
 package Log::Log4perl::Config::Watch;
 
+use constant DEBUG => 0;
+
 our $NEXT_CHECK_TIME;
 
 ###########################################
@@ -50,9 +52,12 @@ sub change_detected {
 
     $time = time() unless defined $time;
 
+    print "Calling change_detected (time=$time)\n" if DEBUG;
+
         # Do we need to check?
     if($self->{_last_checked_at} + 
        $self->{check_interval} > $time) {
+        print "No need to check\n" if DEBUG;
         return ""; # don't need to check, return false
     }
        
@@ -65,9 +70,12 @@ sub change_detected {
 
     if($new_timestamp > $self->{_last_timestamp}) {
         $self->{_last_timestamp} = $new_timestamp;
+        print "Change detected (store=$new_timestamp)!\n" if DEBUG;
         return 1; # Has changed
     }
        
+    print "Hasn't changed (file=$new_timestamp ",
+          "stored=$self->{_last_timestamp})!\n" if DEBUG;
     return "";  # Hasn't changed
 }
 
